pub fn walk_shape(
shape: &'static Shape,
visitor: &mut impl ShapeVisitor,
) -> WalkStatusExpand description
Walk a Shape tree depth-first, calling visitor at each node.
See the module docs for traversal order and control semantics.
pub fn walk_shape(
shape: &'static Shape,
visitor: &mut impl ShapeVisitor,
) -> WalkStatusWalk a Shape tree depth-first, calling visitor at each node.
See the module docs for traversal order and control semantics.