Enum PathStep
Source pub enum PathStep {
Field(u32),
Index(u32),
Variant(u32),
MapKey(u32),
MapValue(u32),
OptionSome,
Deref,
Inner,
Proxy,
}
A single step in a path through a type structure.
Each step records an index that can be used to navigate
back through a Shape to reconstruct field names and types.
Navigate to a struct field by index
Navigate to a list/array element by index
Navigate to an enum variant by index
Navigate into a map key at a specific entry index.
The entry index distinguishes paths for different map keys’ inner frames.
Navigate into a map value at a specific entry index.
The entry index distinguishes paths for different map values’ inner frames.
Navigate into Some of an Option
Navigate through a pointer/reference
Navigate into a transparent inner type (e.g., NonZero<T> -> T)
Navigate into a proxy type (e.g., Inner with #[facet(proxy = InnerProxy)])
This step distinguishes a proxy frame from its parent in the deferred
processing path, so both can be stored without path collisions.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Compares and returns the maximum of two values.
Read more
Compares and returns the minimum of two values.
Read more
Restrict a value to a certain interval.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more
Tests less than (for
self and
other) and is used by the
< operator.
Read more
Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more
Tests greater than (for
self and
other) and is used by the
>
operator.
Read more
Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.